==> media-biz-1.0.0-20161020.084640-4-sources.jar: cn/com/duiba/tuia/media/service/ActivityStatisticsDayService.java <==
/**
 * Project Name:media-biz<br>
 * File Name:ActivityStatisticsDayService.java<br>
 * Package Name:cn.com.duiba.tuia.media.service<br>
 * Date:2016年10月18日下午3:28:09<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.media.service;

import java.util.List;

import cn.com.duiba.tuia.media.common.exception.TuiaMediaException;
import cn.com.duiba.tuia.media.domain.ActivityStatisticsDayDto;
import cn.com.duiba.tuia.media.model.req.ReqActivityData;

/**
 * ClassName: ActivityStatisticsDayService <br/>
 * Function: 活动数据. <br/>
 * date: 2016年10月18日 下午3:28:09 <br/>
 *
 * @author leiliang
 * @version
 * @since JDK 1.6
 */
public interface ActivityStatisticsDayService {

    /**
     * 查询符合条件的记录总数.
     *
     * @param req the req
     * @return the int
     * @throws TuiaMediaException the tuia media exception
     */
    int selectAmountByPage(ReqActivityData req) throws TuiaMediaException;

    /**
     * 查询符合条件的记录列表.
     *
     * @param req the req
     * @return the list< activity statistics day dto>
     * @throws TuiaMediaException the tuia media exception
     */
    List<ActivityStatisticsDayDto> selectListByPage(ReqActivityData req) throws TuiaMediaException;
    
    /**
     * 查询单个活动明细的记录总数.
     *
     * @param req the req
     * @return the int
     * @throws TuiaMediaException the tuia media exception
     */
    int selectAmountByDetail(ReqActivityData req) throws TuiaMediaException;

    /**
     * 查询单个活动明细的记录列表.
     *
     * @param req the req
     * @return the list< activity statistics day dto>
     * @throws TuiaMediaException the tuia media exception
     */
    List<ActivityStatisticsDayDto> selectListByDetail(ReqActivityData req) throws TuiaMediaException;

}

==> media-biz-1.0.22.4-20170117.095351-1-sources.jar: cn/com/duiba/tuia/media/service/ActivityStatisticsDayService.java <==
/**
 * Project Name:media-biz<br>
 * File Name:ActivityStatisticsDayService.java<br>
 * Package Name:cn.com.duiba.tuia.media.service<br>
 * Date:2016年10月18日下午3:28:09<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.media.service;

import java.util.List;

import cn.com.duiba.tuia.media.common.exception.TuiaMediaException;
import cn.com.duiba.tuia.media.domain.ActivityStatisticsDayDto;
import cn.com.duiba.tuia.media.model.req.ReqActivityData;

/**
 * ClassName: ActivityStatisticsDayService <br/>
 * Function: 活动数据. <br/>
 * date: 2016年10月18日 下午3:28:09 <br/>
 *
 * @author leiliang
 * @version
 * @since JDK 1.6
 */
public interface ActivityStatisticsDayService {

    /**
     * 查询符合条件的记录总数.
     *
     * @param req the req
     * @return the int
     * @throws TuiaMediaException the tuia media exception
     */
    int selectAmountByPage(ReqActivityData req) throws TuiaMediaException;

    /**
     * 查询符合条件的记录列表.
     *
     * @param req the req
     * @return the list< activity statistics day dto>
     * @throws TuiaMediaException the tuia media exception
     */
    List<ActivityStatisticsDayDto> selectListByPage(ReqActivityData req) throws TuiaMediaException;

    /**
     * 查询单个活动明细的记录总数.
     *
     * @param req the req
     * @return the int
     * @throws TuiaMediaException the tuia media exception
     */
    int selectAmountByDetail(ReqActivityData req) throws TuiaMediaException;

    /**
     * 查询单个活动明细的记录列表.
     *
     * @param req the req
     * @return the list< activity statistics day dto>
     * @throws TuiaMediaException the tuia media exception
     */
    List<ActivityStatisticsDayDto> selectListByDetail(ReqActivityData req) throws TuiaMediaException;

    /**
     * 
     * selectExposureAndLaunchAdvert:(查询活动的曝光数和发券数，用来计算SPM). <br/>
     *
     * @author ZFZ
     * @param activityIds 活动ID列表
     * @param activityAppId 媒体ID
     * @return
     * @throws TuiaMediaException
     * @since JDK 1.6
     */
    List<ActivityStatisticsDayDto> selectExposureAndLaunchAdvert(List<Long> activityIds,
                                                                 Long activityAppId) throws TuiaMediaException;

}
